@@ -10,6 +10,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from typing import Any
+
 from testinfra.modules.base import InstanceModule
 
 
@@ -23,7 +25,7 @@ def int_or_float(value):
             return value
 
 
-class _Process(dict):
+class _Process(dict[str, Any]):
     def __getattr__(self, key):
         try:
             return self.__getitem__(key)
