@@ -10,16 +10,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import functools
 import re
 
 from testinfra.modules.base import InstanceModule
-from testinfra.utils import cached_property
 
 
 class SystemInfo(InstanceModule):
     """Return system information"""
 
-    @cached_property
+    @functools.cached_property
     def sysinfo(self):
         sysinfo = {
             "type": None,
@@ -50,21 +50,6 @@ class SystemInfo(InstanceModule):
     def _get_linux_sysinfo(self):
         sysinfo = {}
 
-        # LSB
-        lsb = self.run("lsb_release -a")
-        if lsb.rc == 0:
-            for line in lsb.stdout.splitlines():
-                key, value = line.split(":", 1)
-                key = key.strip().lower()
-                value = value.strip().lower()
-                if key == "distributor id":
-                    sysinfo["distribution"] = value
-                elif key == "release":
-                    sysinfo["release"] = value
-                elif key == "codename":
-                    sysinfo["codename"] = value
-            return sysinfo
-
         # https://www.freedesktop.org/software/systemd/man/os-release.html
         os_release = self.run("cat /etc/os-release")
         if os_release.rc == 0:
@@ -79,7 +64,7 @@ class SystemInfo(InstanceModule):
                             line[len(key) :].replace('"', "").replace("'", "").strip()
                         )
             # Arch doesn't have releases
-            if sysinfo["distribution"] == "arch":
+            if "distribution" in sysinfo and sysinfo["distribution"] == "arch":
                 sysinfo["release"] = "rolling"
             return sysinfo
 
@@ -100,6 +85,21 @@ class SystemInfo(InstanceModule):
             sysinfo["release"] = alpine_release.stdout.strip()
             return sysinfo
 
+        # LSB
+        lsb = self.run("lsb_release -a")
+        if lsb.rc == 0:
+            for line in lsb.stdout.splitlines():
+                key, value = line.split(":", 1)
+                key = key.strip().lower()
+                value = value.strip().lower()
+                if key == "distributor id":
+                    sysinfo["distribution"] = value
+                elif key == "release":
+                    sysinfo["release"] = value
+                elif key == "codename":
+                    sysinfo["codename"] = value
+            return sysinfo
+
         return sysinfo
 
     def _get_darwin_sysinfo(self):
